# -*- coding: utf-8 -*-
# PyBEST: Pythonic Black-box Electronic Structure Tool
# Copyright (C) 2016-- The PyBEST Development Team
#
# This file is part of PyBEST.
#
# PyBEST is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# PyBEST is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>
#
# --

import pytest


def pytest_addoption(parser):
    parser.addoption(
        "--all", action="store_true", default=False, help="run all tests"
    )
    parser.addoption(
        "--slow", action="store_true", default=False, help="run slow tests"
    )
    parser.addoption(
        "--loglevel", action="store", default="0", help="set global log level"
    )


def pytest_configure(config):
    config.addinivalue_line("markers", "slow: mark test as slow to run")
    loglevel = int(config.getoption("--loglevel"))
    from pybest.log import log
    log.level = loglevel


def pytest_collection_modifyitems(config, items):
    if config.getoption("--all"):
        # --all given in cli: do not skip slow tests
        return
    elif config.getoption("--slow"):
        # do only slow tests
        skip_fast = pytest.mark.skip(reason="--slow option has been selected")
        for item in items:
            if "slow" not in item.keywords:
                item.add_marker(skip_fast)
        return
    skip_slow = pytest.mark.skip(reason="need --all or --slow option to run")
    for item in items:
        if "slow" in item.keywords:
            item.add_marker(skip_slow)


def pytest_sessionfinish(session, exitstatus):
    import shutil
    import pathlib

    pybesttmp = pathlib.Path("pybest-temp")
    pybestres = pathlib.Path("pybest-results")

    if pybesttmp.exists():
        shutil.rmtree(pybesttmp)
    if pybestres.exists():
        shutil.rmtree(pybestres)
