#!/usr/bin/env python

from pybest import context
from pybest.ee_eom.eom_pccd import REOMpCCD
from pybest.gbasis import get_gobasis
from pybest.gbasis.gobasis import (
    compute_dipole,
    compute_eri,
    compute_kinetic,
    compute_nuclear,
    compute_nuclear_repulsion,
    compute_overlap,
)
from pybest.geminals.rpccd import RpCCD
from pybest.linalg.dense import DenseLinalgFactory
from pybest.ee_eom.eom_pccd import REOMpCCD
from pybest.ee_eom.eom_pccd_s import REOMpCCDS
from pybest.scf import AufbauOccModel
from pybest.wrappers.hf import RHF


###############################################################################
## Set up molecule, define basis set ##########################################
###############################################################################
# get the XYZ file from PyBEST's test data directory
fn_xyz = context.get_fn("test/water.xyz")
obasis = get_gobasis("cc-pvdz", fn_xyz)
###############################################################################
## Define Occupation model, expansion coefficients and overlap ################
###############################################################################
lf = DenseLinalgFactory(obasis.nbasis)
occ_model = AufbauOccModel(5)
orb_a = lf.create_orbital(obasis.nbasis)
olp = compute_overlap(obasis)
###############################################################################
## Construct Hamiltonian ######################################################
###############################################################################
kin = compute_kinetic(obasis)
ne = compute_nuclear(obasis)
eri = compute_eri(obasis)
external = compute_nuclear_repulsion(obasis)

###############################################################################
## Do a Hartree-Fock calculation ##############################################
###############################################################################
hf = RHF(lf, occ_model)
hf_ = hf(kin, ne, eri, external, olp, orb_a)

###############################################################################
## Do OO-pCCD optimization ####################################################
###############################################################################
oopccd = RpCCD(lf, occ_model)
oopccd_ = oopccd(kin, ne, eri, hf_)

################################################################################
### Do REOM-pCCD calculation ###################################################
################################################################################
eom = REOMpCCD(lf, occ_model)
eom_ = eom(kin, ne, eri, oopccd_, nroot=3)

################################################################################
### Do REOM-pCCD+S calculation #################################################
################################################################################
eom = REOMpCCDS(lf, occ_model)
eom_ = eom(kin, ne, eri, oopccd_, nroot=3)

################################################################################
### Do REOM-pCCD calculation davidson              #############################
################################################################################
eom = REOMpCCD(lf, occ_model)
eom_ = eom(kin, ne, eri, oopccd_, nroot=3, davidson=True)
