#!/usr/bin/env python
# JSON {"lot": "RHF/6-31G",
# JSON  "scf": "PlainSCFSolver",
# JSON  "linalg": "CholeskyLinalgFactory",
# JSON  "difficulty": 1,
# JSON  "description": "Basic RHF example with Cholesky matrices, includes export of Hamiltonian"}

import numpy as np

from pybest import context
from pybest.gbasis import get_gobasis
from pybest.gbasis.gobasis import (
    compute_cholesky_eri,
    compute_kinetic,
    compute_nuclear,
    compute_nuclear_repulsion,
    compute_overlap,
)
from pybest.linalg.cholesky import CholeskyLinalgFactory
from pybest.scf import AufbauOccModel
from pybest.wrappers.hf import RHF


# Hartree-Fock calculation
# ------------------------

# Construct a molecule from scratch
# Create a Gaussian basis set
gobasis = get_gobasis("cc-pvdz", context.get_fn("test/h2.xyz"))

# Create a linalg factory
lf = CholeskyLinalgFactory(gobasis.nbasis)

# Compute integrals
olp = compute_overlap(gobasis)
kin = compute_kinetic(gobasis)
na = compute_nuclear(gobasis)
# set CD threshold to 1e-8 (default 1e-3)
er = compute_cholesky_eri(gobasis, threshold=1e-8)
external = compute_nuclear_repulsion(gobasis)

# Create alpha orbitals
orb_a = lf.create_orbital()

# Decide how to occupy the orbitals (1 alpha electron)
occ_model = AufbauOccModel(1)

# Converge WFN
hf = RHF(lf, occ_model)
hf_ = hf(kin, na, er, external, olp, orb_a)

# Write SCF results to a molden file
hf_.gobasis = gobasis
hf_.to_file("h2-scf.molden")
