#!/usr/bin/env python
# JSON {"lot": "RHF/cc-pVDZ",
# JSON  "scf": "PlainSCFSolver",
# JSON  "linalg": "CholeskyLinalgFactory",
# JSON  "difficulty": 2,
# JSON  "description": "Basic RHF example with Cholesky decomposition of the ERI"}

from pybest import context
from pybest.gbasis import get_gobasis
from pybest.gbasis.gobasis import (
    compute_cholesky_eri,
    compute_kinetic,
    compute_nuclear,
    compute_nuclear_repulsion,
    compute_overlap,
)
from pybest.linalg.cholesky import CholeskyLinalgFactory
from pybest.scf import AufbauOccModel
from pybest.wrappers.hf import RHF


# Load the coordinates from file.
fn_xyz = context.get_fn("test/water.xyz")
# Create a Gaussian basis set
gobasis = get_gobasis("cc-pvdz", fn_xyz)

# Create a linalg factory
lf = CholeskyLinalgFactory(gobasis.nbasis)

# Compute integrals
olp = compute_overlap(gobasis)
kin = compute_kinetic(gobasis)
na = compute_nuclear(gobasis)
# set CD threshold to 1e-8 (default 1e-3)
er = compute_cholesky_eri(gobasis, threshold=1e-8)
external = compute_nuclear_repulsion(gobasis)

# Create alpha orbitals
orb_a = lf.create_orbital()

# Decide how to occupy the orbitals (5 alpha electrons)
occ_model = AufbauOccModel(5)

# Converge WFN
hf = RHF(lf, occ_model)
hf_ = hf(kin, na, er, external, olp, orb_a)

# Write SCF results to a file
hf_.gobasis = gobasis
hf_.to_file("water-scf.molden")
