#!/usr/bin/env python

from pybest import context
from pybest.gbasis import get_gobasis
from pybest.gbasis.gobasis import (
    compute_dipole,
    compute_eri,
    compute_kinetic,
    compute_nuclear,
    compute_nuclear_repulsion,
    compute_overlap,
)
from pybest.linalg.dense import DenseLinalgFactory
from pybest.pt import RMP2
from pybest.scf import AufbauOccModel
from pybest.wrappers.hf import RHF


###############################################################################
## Set up molecule, define basis set ##########################################
###############################################################################
# get the XYZ file from PyBEST's test data directory
fn_xyz = context.get_fn("test/water.xyz")
obasis = get_gobasis("cc-pvdz", fn_xyz)
###############################################################################
## Define Occupation model, expansion coefficients and overlap ################
###############################################################################
lf = DenseLinalgFactory(obasis.nbasis)
occ_model = AufbauOccModel(5)
orb_a = lf.create_orbital(obasis.nbasis)
olp = compute_overlap(obasis)
###############################################################################
## Construct Hamiltonian ######################################################
###############################################################################
kin = compute_kinetic(obasis)
ne = compute_nuclear(obasis)
eri = compute_eri(obasis)
external = compute_nuclear_repulsion(obasis)

###############################################################################
## Do a Hartree-Fock calculation ##############################################
###############################################################################
hf = RHF(lf, occ_model)
hf_ = hf(kin, ne, eri, external, olp, orb_a)

###############################################################################
## Do SCS RMP2 calculation with fos=0.3 and fss=1.2 ###########################
###############################################################################
mp2 = RMP2(lf, occ_model)
mp2_ = mp2(kin, ne, eri, hf_, fos=0.3, fss=1.2)

###############################################################################
## Do SCS RMP2 calculation with fos=0.3 and fss=1.2 ###########################
## AND determine natural orbitals INCLUDING orbital relaxation contributions ##
###############################################################################
mp2 = RMP2(lf, occ_model)
mp2_ = mp2(kin, ne, eri, hf_, natorb=True, relaxation=True, fos=0.3, fss=1.2)
