# -*- coding: utf-8 -*-
# PyBEST: Pythonic Black-box Electronic Structure Tool
# Copyright (C) 2016-- The PyBEST Development Team
#
# This file is part of PyBEST.
#
# PyBEST is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# PyBEST is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>
#
# --
# pylint: skip-file


import numpy as np
import pytest

from pybest.ee_eom.eom_ccs import REOMCCS
from pybest.cc.rccs import RHFCCS
from pybest.ee_eom.test.common import prepare_mol


# Reference energies
# HF orbitals
e_ex_ccs_hf_ref = [
    0.000000e00,
    1.053411e-01,
    1.053411e-01,
    4.976920e-01,
    5.523241e-01,
    5.523241e-01,
    6.390127e-01,
    6.474507e-01,
    6.474507e-01,
    6.478041e-01,
    7.284261e-01,
    7.498812e-01,
    7.498812e-01,
    7.861793e-01,
    8.673948e-01,
    9.553334e-01,
]

e_ex_ccs_hf_ref_fc = [
    0.000000e00,
    1.054322e-01,
    1.054322e-01,
    4.977093e-01,
]


def test_ccs_hf_davidson():
    lf, occ_model, one, er, iodata = prepare_mol("test/chplus.fcidump", 3, 25)

    # RHF-CCS
    ccs = RHFCCS(lf, occ_model)
    ccs_ = ccs(one, er, iodata, tthreshold=1e-10)

    assert abs(ccs_.e_corr - 0.00) < 1e-6
    assert abs(ccs_.e_corr_s - 0.00) < 1e-6

    # EOM-CCS/CIS
    eom = REOMCCS(lf, occ_model)
    eom_ = eom(one, er, ccs_, nroot=16, davidson=True, todisk=False,)

    for i in range(len(e_ex_ccs_hf_ref)):
        assert abs(eom_.e_ee[i] - e_ex_ccs_hf_ref[i]) < 1e-6


def test_ccs_hf_davidson_ncore():
    lf, occ_model, one, er, iodata = prepare_mol("test/chplus.fcidump", 3, 25)

    # RHF-CCS
    ccs = RHFCCS(lf, occ_model, ncore=1)
    ccs_ = ccs(one, er, iodata, tthreshold=1e-10)

    # EOM-CCS/CIS
    eom = REOMCCS(lf, occ_model, ncore=1)
    eom_ = eom(one, er, ccs_, nroot=4, davidson=True, todisk=False,)

    for i in range(len(e_ex_ccs_hf_ref_fc)):
        assert abs(eom_.e_ee[i] - e_ex_ccs_hf_ref_fc[i]) < 1e-6
