# -*- coding: utf-8 -*-
# PyBEST: Pythonic Black-box Electronic Structure Tool
# Copyright (C) 2016-- The PyBEST Development Team
#
# This file is part of PyBEST.
#
# PyBEST is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# PyBEST is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>
#
# --
"""Definition of all exceptions in PyBEST"""


class PyBestException(Exception):
    """Base class for all the exceptions raised within the PyBest package
    """

    pass


class ProjectionError(PyBestException):
    """Exception raised when projection of orbitals was unsuccessful
    """

    pass


class GOBasisError(PyBestException, ValueError):
    """Exception raised when Basis set was read in unsuccessful
    """

    pass


class ElectronCountError(PyBestException, ValueError):
    """Exception raised when a negative number of electron is encountered, or
       when more electrons than basis functions are requested
    """

    pass


class NoConvergence(PyBestException):
    """Exception raised when an optimization algorithm does not reach the convergence
       threshold in the specified number of iterations"""

    pass


class NoSCFConvergence(PyBestException):
    """Exception raised when an SCF algorithm does not reach the convergence
       threshold in the specified number of iterations"""

    pass


class UnknownHamiltonian(PyBestException, ValueError):
    """Exception raised when the Hamiltonian contains unkown terms"""

    pass


class UnknownOption(PyBestException, ValueError):
    """Exception raised when unkown value is provided"""

    pass


class EmptyData(PyBestException, ValueError):
    """Exception raised when input data is empty/not provided"""

    pass


class NonEmptyData(PyBestException, ValueError):
    """Exception raised when input data is not empty"""

    pass


class SymmetryError(PyBestException, ValueError):
    """Exception raised when object does not have proper symmetry"""

    pass


class ConsistencyError(PyBestException, ValueError):
    """Exception raised when calculation results in unexpected outcome"""

    pass


class ArgumentError(PyBestException):
    """Exception raised when unkown argument is provided"""

    pass


class RestartError(PyBestException):
    """Exception raised when restarting from checkpoit fails"""

    pass


class FileNotFoundError(PyBestException):
    """Exception raised when required file is not found"""

    pass


class DirectoryError(PyBestException):
    """Exception raised when directory is not found nor created"""

    pass

class MatrixShapeError(PyBestException):
    """Exception raised when matrix shape does not allow to make operation."""

    pass


class FeasibilityError(PyBestException):
    """Error raised when the problem appears to be infeasible"""

    pass


class BoundedError(PyBestException):
    """Error raised when the problem appears to be unbounded"""

    pass
