# -*- coding: utf-8 -*-
# PyBEST: Pythonic Black-box Electronic Structure Tool
# Copyright (C) 2016-- The PyBEST Development Team
#
# This file is part of PyBEST.
#
# PyBEST is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# PyBEST is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>
#
# --
# pylint: skip-file


import pytest

from pybest.io.lockedh5 import LockedH5File
from pybest.test.common import tmpdir


def test_locked1():
    # just a silly test
    with tmpdir("pybest.scripts.test.test_common.test_locked1") as dn:
        with LockedH5File(f"{dn}/foo.h5", mode="w") as f:
            pass


def test_locked2():
    # test error handling in h5.File constructor
    with pytest.raises(IOError):
        with tmpdir("pybest.scripts.test.test_common.test_locked2") as dn:
            with LockedH5File(
                f"{dn}/foo.h5", mode="r", wait=0.1, count=3
            ) as f:
                pass


def test_locked3():
    # test error handling in h5.File constructor
    with pytest.raises(ValueError):
        with LockedH5File(
            "pybest.scripts.test.test_common.test_locked3.h5",
            driver="fubar",
            wait=0.1,
            count=3,
        ) as f:
            pass


def test_locked4():
    # test error handling of wrong driver
    with pytest.raises(ValueError):
        with tmpdir("pybest.scripts.test.test_common.test_locked4") as dn:
            with LockedH5File(f"{dn}/foo.h5", driver="core", mode="w") as f:
                pass


def test_locked5():
    # test error handling in with clause
    with pytest.raises(RuntimeError):
        with tmpdir("pybest.scripts.test.test_common.test_locked5") as dn:
            with LockedH5File(f"{dn}/foo.h5", mode="w") as f:
                raise RuntimeError
