# -*- coding: utf-8 -*-
# PyBEST: Pythonic Black-box Electronic Structure Tool
# Copyright (C) 2016-- The PyBEST Development Team
#
# This file is part of PyBEST.
#
# PyBEST is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# PyBEST is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>
#
# --
#
# pylint: skip-file

import numpy as np
import pytest

from pybest.context import context
from pybest.gbasis.gobasis import (
    compute_eri,
    compute_kinetic,
    compute_nuclear,
    compute_nuclear_repulsion,
    compute_overlap,
    get_gobasis,
)
from pybest.io.iodata import IOData
from pybest.linalg import DenseLinalgFactory
from pybest.scf.occ import AufbauOccModel


def prepare_mol(basis, filen, orbfilen, nocc=5):
    fn_xyz = context.get_fn(filen)
    obasis = get_gobasis(basis, fn_xyz, print_basis=False)
    lf = DenseLinalgFactory(obasis.nbasis)
    olp = compute_overlap(obasis)
    kin = compute_kinetic(obasis)
    na = compute_nuclear(obasis)
    one = kin.copy()
    one.iadd(na)
    er = compute_eri(obasis)
    external = compute_nuclear_repulsion(obasis)

    fn_orb = context.get_fn(orbfilen)
    orb_ = np.fromfile(fn_orb, sep=",").reshape(obasis.nbasis, obasis.nbasis)
    orb_a = lf.create_orbital()
    orb_a._coeffs = orb_

    occ_model = AufbauOccModel(nocc)

    return lf, olp, orb_a, one, er, external, occ_model
