# -*- coding: utf-8 -*-
# PyBEST: Pythonic Black-box Electronic Structure Tool
# Copyright (C) 2016-- The PyBEST Development Team
#
# This file is part of PyBEST.
#
# PyBEST is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# PyBEST is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>
#
# --
# pylint: skip-file


import numpy as np
import pytest

from pybest.linalg.dense import DenseLinalgFactory
from pybest.scf.occ import AufbauOccModel


def test_occ_aufbau_cs():
    lf = DenseLinalgFactory(10)
    orb = lf.create_orbital()

    # integer
    occ_model = AufbauOccModel(3)
    occ_model.assign(orb)
    assert abs(orb.occupations[:4] - [1.0, 1.0, 1.0, 0.0]).max() < 1e-10

    # fractional 1
    occ_model = AufbauOccModel(2.9)
    occ_model.assign(orb)
    assert abs(orb.occupations[:4] - [1.0, 1.0, 0.9, 0.0]).max() < 1e-10

    # fractional 2
    occ_model = AufbauOccModel(2.8)
    occ_model.assign(orb)
    assert abs(orb.occupations[:4] - [1.0, 1.0, 0.8, 0.0]).max() < 1e-10


def test_occ_aufbau_os():
    lf = DenseLinalgFactory(10)
    orb_alpha = lf.create_orbital()
    orb_beta = lf.create_orbital()

    # integer
    occ_model = AufbauOccModel(3, 4)
    occ_model.assign(orb_alpha, orb_beta)
    assert (
        abs(orb_alpha.occupations[:5] - [1.0, 1.0, 1.0, 0.0, 0.0]).max()
        < 1e-10
    )
    assert (
        abs(orb_beta.occupations[:5] - [1.0, 1.0, 1.0, 1.0, 0.0]).max() < 1e-10
    )

    # fractional
    occ_model = AufbauOccModel(2.9, 3.1)
    occ_model.assign(orb_alpha, orb_beta)
    assert (
        abs(orb_alpha.occupations[:5] - [1.0, 1.0, 0.9, 0.0, 0.0]).max()
        < 1e-10
    )
    assert (
        abs(orb_beta.occupations[:5] - [1.0, 1.0, 1.0, 0.1, 0.0]).max() < 1e-10
    )
