# -*- coding: utf-8 -*-
# PyBEST: Pythonic Black-box Electronic Structure Tool
# Copyright (C) 2016-- The PyBEST Development Team
#
# This file is part of PyBEST.
#
# PyBEST is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# PyBEST is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>
#
# --
# pylint: skip-file


import numpy as np

from pybest.context import context
from pybest.gbasis.gobasis import get_gobasis
from pybest.utils import get_com
from pybest.linalg.dense import DenseLinalgFactory
from pybest.scf.occ import AufbauOccModel, FixedOccModel
from pybest.gbasis.gobasis import (
    compute_overlap,
    compute_kinetic,
    compute_nuclear,
    compute_eri,
    compute_nuclear_repulsion,
    compute_dipole,
)


__all__ = [
    "prepare_hf",
]


def prepare_hf(basis, molfile, *nocc):
    fn = context.get_fn(molfile)
    obasis = get_gobasis(basis, fn, print_basis=False)
    ###########################################################################
    ### Define Occupation model, expansion coefficients and overlap ###########
    ###########################################################################
    lf = DenseLinalgFactory(obasis.nbasis)
    occ_model = AufbauOccModel(*nocc)
    orb = [lf.create_orbital(obasis.nbasis) for i in range(len(nocc))]
    olp = compute_overlap(obasis)
    ###########################################################################
    ### Construct Hamiltonian #################################################
    ###########################################################################
    kin = compute_kinetic(obasis)
    na = compute_nuclear(obasis)
    er = compute_eri(obasis)
    external = compute_nuclear_repulsion(obasis)
    ###########################################################################
    ## Return output for HF calculations ######################################
    ###########################################################################

    return lf, occ_model, olp, orb, kin, na, er, external, obasis


def prepare_dipole(gobasis):
    com = get_com(gobasis)
    dipole = compute_dipole(gobasis, x=com[0], y=com[1], z=com[2])

    return dipole
